.. _index:

.. _first-example:

.. include:: ../README.rst
    :start-after: readme-start
    :end-before: readme-end

.. image:: _static/dev_data_generator_to_trash.png
    :width: 75%

.. toctree::
    :maxdepth: 3
    :hidden:

    getting_started
    history
    installation
    sch_usage
    sdc_usage
    api
